@@ -1,4 +1,4 @@
-var fs = require('fs');
-var ansiEscapes = require('./');
+const fs = require('fs');
+const ansiEscapes = require('.');
 
 console.log(ansiEscapes.image(fs.readFileSync('fixture.jpg'), {width: 15}));
